import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { max, scaleSqrt, scaleLinear } from 'd3';

import { Marks } from './Marks';
import { useWorldAtlas } from './useWorldAtlas';
import { useCities } from './useCities';
import { useGeoLines } from './useGeoLines';

const width = 960;
const height = 500;
let spin = [205];

const App = () => {
  const worldAtlas = useWorldAtlas();
  const cities = useCities();
  const geoLines = useGeoLines();

  if (!worldAtlas  || !cities || !geoLines) {
    return <pre>Loading...</pre>;
  }
  
  const sizeValue = d => d.population;
  const maxRadius = 15;
  const sizeScale = scaleSqrt()
  	.domain([0, max(cities, sizeValue)])
  	.range([0, maxRadius])
  
  const coSizeValue = d => d.properties.pop;
  const maxOpacity = 30;
  const coSizeScale = scaleLinear()
  	.domain([0, max(worldAtlas.countries.features, coSizeValue)])
  	.range([0, maxOpacity])
  
  return (
    <svg width={width} height={height} className="ok">
      <g>
        <Marks
          geoLines={geoLines}
          worldAtlas={worldAtlas}
          cities={cities}
          sizeScale={sizeScale}
          sizeValue={sizeValue}
          coSizeValue={coSizeValue}
          coSizeScale={coSizeScale}
          spin={spin}
        />
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
