import { useState, useEffect } from 'react';
import { json } from 'd3'
import { feature, mesh } from 'topojson';

import { useWorldPop } from './useWorldPop';

const jsonUrl = 'https://unpkg.com/world-atlas@2.0.2/countries-50m.json';

export const useWorldAtlas = () => {
  const [data, setData] = useState(null);
  const worldPop = useWorldPop();
  
  if (!worldPop) {
    return null
  }
  
  useEffect(() => {
    json(jsonUrl).then(topology => {
      const { countries, land } = topology.objects;
      countries.geometries.map((c) => {
        c.properties.pop = worldPop[c.properties.name] ? worldPop[c.properties.name] : 0;
      });
    	setData({
        all: topology,
        land: feature(topology, land),
        countries: feature(topology, countries),
        interiors: mesh(topology, countries, (a, b) => a !== b)
      });
    });
  }, []);

      //console.log(data)
  return data;
};
